Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'lib/public/UserMigration/IMigrator.php')
-rw-r--r--lib/public/UserMigration/IMigrator.php23
1 files changed, 22 insertions, 1 deletions
diff --git a/lib/public/UserMigration/IMigrator.php b/lib/public/UserMigration/IMigrator.php
index c97fb3c0bca..d02e5df0683 100644
--- a/lib/public/UserMigration/IMigrator.php
+++ b/lib/public/UserMigration/IMigrator.php
@@ -60,6 +60,27 @@ interface IMigrator {
): void;
/**
+ * Returns the unique ID
+ *
+ * @since 24.0.0
+ */
+ public function getId(): string;
+
+ /**
+ * Returns the display name
+ *
+ * @since 24.0.0
+ */
+ public function getDisplayName(): string;
+
+ /**
+ * Returns the description
+ *
+ * @since 24.0.0
+ */
+ public function getDescription(): string;
+
+ /**
* Returns the version of the export format for this migrator
*
* @since 24.0.0
@@ -68,7 +89,7 @@ interface IMigrator {
/**
* Checks whether it is able to import a version of the export format for this migrator
* Use $importSource->getMigratorVersion(static::class) to get the version from the archive
*
* @since 24.0.0
*/
@@ -68,7 +89,7 @@ interface IMigrator {
/**
* Checks whether it is able to import a version of the export format for this migrator
- * Use $importSource->getMigratorVersion(static::class) to get the version from the archive
+ * Use $importSource->getMigratorVersion($this->getId()) to get the version from the archive
*
* @since 24.0.0